# xc

Exchange-correlation functional implementations and utility functions.

| File                  | Description |
| :-------------------: | :---------: |
| lda_c_chachiyo.py     | Chachiyo correlation |
| lda_c_chachiyo_mod.py | Modified Chachiyo correlation |
| lda_c_pw.py           | PW correlation |
| lda_c_pw_mod.py       | Modified PW correlation |
| lda_c_vwn.py          | VWN correlation |
| lda_x.py              | Slater exchange |
| utils.py              | Utility functions |
